@@ -1,4 +1,4 @@
-/* $Id: demowindow.cc,v 1.47 2004/03/14 14:48:12 murrayc Exp $ */
+/* $Id: demowindow.cc,v 1.45 2002/12/27 12:05:23 daniel Exp $ */
 
 /* Copyright (C) 2001 The gtkmm Development Team
  *
@@ -31,17 +31,6 @@
 #include <cctype>
 #include <cerrno>
 
-//The SUN Forte compiler can't seem to either find the declarations or the implementations,
-//so these are not used on that platform.
-//#include <stdio.h> //Needed by the SUN Forte compiler, for flockfile().
-//SUN Forte seems to need these:
-//void flockfile(FILE*);
-//void funlockfile(FILE*);
-#ifdef GLIBMM_COMPILER_SUN_FORTE
-  //These don't wotk even though the configure-time check works.
-  #undef HAVE_FLOCKFILE
-  #undef HAVE_FUNLOCKFILE
-#endif
 
 namespace
 {
@@ -306,8 +295,7 @@ void DemoWindow::load_file(const std::string& filename)
     	    {
     	      Gtk::TextIter end = start;
 
-    	      // The SUN Forte compiler says this is a badly formed expression.
-              //g_assert (int(strlen(p)) >= (q - p)); //TODO: What is this for?  daniel.
+    	      g_assert (int(strlen(p)) >= (q - p)); //TODO: What is this for?  daniel.
 
               const Glib::ustring strTemp (p, q);
     	      end = refBufferInfo->insert(end, strTemp);
@@ -350,8 +338,7 @@ void DemoWindow::load_file(const std::string& filename)
                       start = refBufferInfo->insert(start, " ");
                     }
 
-                  // The SUN Forte compiler says this is a badly formed expression.
-                  // g_assert (int(strlen(p)) >= len); //TODO: What is this for?  daniel.
+                  g_assert (int(strlen(p)) >= len); //TODO: What is this for?  daniel.
 
                   start = refBufferInfo->insert(start, Glib::ustring(p, p + len));
                   in_para = 1;
